@@ -282,25 +282,25 @@ class Cursor(DBAPICursor):
         else:
             sql = operation % _escaper.escape_args(parameters)
 
-        _logger.info("{}".format(sql))
+        # _logger.info("{}".format(sql))
 
         client = self.connection.client
         self._query_id = client.prepareStatement(sql)
         client.executeStatement(self._query_id)
 
-        _logger.info("getting result metadata")
+        # _logger.info("getting result metadata")
         buffer = client.getResultMetadata(self._query_id)
         buffer = BytesIO(buffer)
         self._rowcount, self._query_columns_description = get_query_columns_info(buffer)
-        _logger.info("finished populating metadata", self._query_id)
+        # _logger.info("finished populating metadata", self._query_id)
         return self._query_id
 
     def rowcount(self):
-        _logger.info("fetch returning the rowcount from e6x itself")
+        # _logger.info("fetch returning the rowcount from e6x itself")
         return self._rowcount
 
     def _fetch_more(self):
-        _logger.info("fetching batch")
+        # _logger.info("fetching batch")
         batch_size = self._arraysize
         self._data = list()
         for i in range(batch_size):
@@ -309,15 +309,15 @@ class Cursor(DBAPICursor):
                 return
             self._data = self._data + rows
 
-        _logger.info("fetched batch of {num}".format(num=len(self._data)))
+        # _logger.info("fetched batch of {num}".format(num=len(self._data)))
         return self._data
 
     def _fetch_all(self):
-        _logger.info("fetching all from overriden method")
+        # _logger.info("fetching all from overriden method")
         self._data = list()
         while True:
-            _logger.info(len(self._data))
-            _logger.info("fetching next batch from fetch all")
+            # _logger.info(len(self._data))
+            # _logger.info("fetching next batch from fetch all")
             rows = self.fetch_batch()
             if rows is None:
                 break
@@ -327,7 +327,7 @@ class Cursor(DBAPICursor):
         return rows
 
     def fetch_batch(self):
-        _logger.debug("fetching next batch from e6data")
+        # _logger.debug("fetching next batch from e6data")
         client = self.connection.client
         buffer = client.getNextResultBatch(self._query_id)
 
@@ -339,16 +339,16 @@ class Cursor(DBAPICursor):
         return read_rows_from_batch(self._query_columns_description, dis)
 
     def fetchall(self):
-        _logger.info("fetching all")
+        # _logger.info("fetching all")
         return self._fetch_all()
 
     def fetchmany(self, size=None):
-        _logger.info("fetching all from overriden method")
+        # _logger.info("fetching all from overriden method")
         if size is None:
             size = self.arraysize
         self._data = list()
         while len(self._data) < size:
-            _logger.info("fetching next batch from fetch many")
+            # _logger.info("fetching next batch from fetch many")
             rows = self.fetch_batch()
             if rows is None:
                 break
@@ -363,7 +363,7 @@ class Cursor(DBAPICursor):
         return rows
 
     def fetchone(self):
-        _logger.info("fetch One returning the batch itself which is limited by predefined no.of rows")
+        # _logger.info("fetch One returning the batch itself which is limited by predefined no.of rows")
         rows_to_return = []
         client = self.connection.client
         buffer = client.getNextResultRow(self._query_id)
